import * as React from 'react';
import { ActivityIndicator, Text, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { withTheme } from '../services/ThemeContext';
class FourDigitComponent extends React.PureComponent {
    render() {
        const { error, spinner, theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(View, { style: styles.container },
            React.createElement(View, { style: styles.interactiveContainer }, spinner ? (React.createElement(ActivityIndicator, { color: theme.primaryText, size: "large" })) : (this.renderDotContainer())),
            React.createElement(View, { style: styles.errorContainer },
                React.createElement(Text, { style: styles.errorText, numberOfLines: 2 }, error))));
    }
    renderDotContainer() {
        const { pin, theme } = this.props;
        const styles = getStyles(theme);
        return (React.createElement(View, { style: styles.dotContainer },
            React.createElement(View, { style: [styles.circle, pin.length > 0 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pin.length > 1 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pin.length > 2 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pin.length > 3 && styles.circleSected] })));
    }
}
export const FourDigit = withTheme(FourDigitComponent);
const getStyles = cacheStyles((theme) => ({
    // used for logging *back in* with PIN
    container: {
        paddingTop: theme.rem(0.75),
        width: '100%',
        height: theme.rem(5.5)
    },
    errorContainer: {
        height: theme.rem(2.5),
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-around'
    },
    errorText: {
        color: theme.dangerText,
        textAlign: 'center',
        fontSize: theme.rem(0.75)
    },
    interactiveContainer: {
        height: theme.rem(2.5),
        width: '100%',
        alignItems: 'center'
    },
    dotContainer: {
        height: '100%',
        width: theme.rem(12),
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    circle: {
        borderWidth: 2,
        borderColor: theme.primaryText,
        borderRadius: theme.rem(1),
        height: theme.rem(2),
        width: theme.rem(2)
    },
    circleSected: {
        backgroundColor: theme.iconTappable,
        borderWidth: 2,
        borderColor: theme.primaryText,
        borderRadius: theme.rem(1),
        height: theme.rem(2),
        width: theme.rem(2)
    }
}));
