import * as React from 'react';
import { ActivityIndicator, TouchableWithoutFeedback, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesomeIcon from 'react-native-vector-icons/FontAwesome';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';
import { withTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
const textHeights = {
    small: 2,
    medium: 3,
    large: 0
};
export class TileComponent extends React.PureComponent {
    render() {
        const { body, title, contentPadding = true, children, theme, type, maximumHeight = 'medium', error, onPress, disabled } = this.props;
        const styles = getStyles(theme);
        const numberOfLines = textHeights[maximumHeight];
        if (type === 'loading') {
            return (React.createElement(View, null,
                React.createElement(View, { style: styles.container },
                    React.createElement(View, { style: [
                            styles.content,
                            contentPadding ? styles.contentPadding : null
                        ] },
                        React.createElement(EdgeText, { style: styles.textHeader }, title),
                        React.createElement(ActivityIndicator, { style: styles.loader, color: theme.primaryText, size: "large" }))),
                React.createElement(View, { style: styles.divider })));
        }
        return (React.createElement(TouchableWithoutFeedback, { onPress: onPress, disabled: type === 'static' || disabled },
            React.createElement(View, null,
                React.createElement(View, { style: styles.container },
                    React.createElement(View, { style: [
                            styles.content,
                            contentPadding ? styles.contentPadding : null
                        ] },
                        type === 'editable' ? (React.createElement(FontAwesomeIcon, { name: "edit", style: styles.editIcon })) : null,
                        type === 'questionable' ? (React.createElement(SimpleLineIcons, { name: "question", style: styles.editIcon })) : null,
                        React.createElement(EdgeText, { style: error ? styles.textHeaderError : styles.textHeader }, title),
                        typeof body === 'string' ? (React.createElement(EdgeText, { style: disabled === true
                                ? styles.textBodyDisabled
                                : styles.textBody, numberOfLines: numberOfLines, ellipsizeMode: "tail" }, body)) : null,
                        children),
                    type === 'touchable' ? (React.createElement(View, { style: styles.iconContainer },
                        React.createElement(FontAwesomeIcon, { name: "chevron-right", style: disabled === true
                                ? styles.arrowIconDeactivated
                                : styles.arrowIcon }))) : null),
                React.createElement(View, { style: styles.divider }))));
    }
}
const getStyles = cacheStyles((theme) => ({
    container: {
        backgroundColor: theme.tileBackground,
        paddingHorizontal: theme.rem(1),
        marginTop: theme.rem(1),
        paddingBottom: theme.rem(1),
        flexDirection: 'row',
        alignItems: 'center'
    },
    content: {
        flex: 1
    },
    contentPadding: {
        paddingLeft: theme.rem(0.25)
    },
    iconContainer: {
        justifyContent: 'center',
        alignItems: 'center'
    },
    arrowIcon: {
        color: theme.iconTappable,
        marginHorizontal: theme.rem(0.5),
        textAlign: 'center'
    },
    textHeader: {
        color: theme.secondaryText,
        fontSize: theme.rem(0.75),
        paddingBottom: theme.rem(0.25),
        paddingRight: theme.rem(1)
    },
    textHeaderError: {
        color: theme.dangerText,
        fontSize: theme.rem(0.75)
    },
    textBody: {
        color: theme.primaryText,
        fontSize: theme.rem(1)
    },
    editIcon: {
        position: 'absolute',
        color: theme.iconTappable,
        width: theme.rem(0.75),
        height: theme.rem(0.75),
        top: theme.rem(0.25),
        right: 0
    },
    loader: {
        marginTop: theme.rem(0.25)
    },
    divider: {
        height: theme.thinLineWidth,
        marginLeft: theme.rem(1),
        borderBottomWidth: theme.thinLineWidth,
        borderBottomColor: theme.lineDivider
    },
    arrowIconDeactivated: {
        color: theme.iconDeactivated,
        marginRight: theme.rem(0.25),
        marginLeft: theme.rem(0.75),
        textAlign: 'center'
    },
    textBodyDisabled: {
        color: theme.deactivatedText,
        fontSize: theme.rem(1)
    }
}));
export const Tile = withTheme(TileComponent);
