import * as React from 'react';
import { Text, View } from 'react-native';
import s from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import { useHandler } from '../../hooks/useHandler';
import * as Styles from '../../styles/index';
import { useDispatch } from '../../types/ReduxTypes';
import { logEvent } from '../../util/analytics';
import { scale } from '../../util/scaling';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { BackgroundImage } from '../common/BackgroundImage';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const LandingScene = (props) => {
    const dispatch = useDispatch();
    const handleCreate = useHandler(() => {
        logEvent('Signup_Create_Account');
        dispatch({ type: 'NEW_ACCOUNT_WELCOME' });
    });
    const handlePassword = useHandler(() => {
        logEvent('Signup_Signin');
        dispatch({ type: 'START_PASSWORD_LOGIN' });
    });
    return (React.createElement(ThemedScene, { branding: props.branding, noUnderline: true },
        React.createElement(BackgroundImageView, { branding: props.branding },
            React.createElement(View, { style: styles.inner },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: props.branding }),
                    React.createElement(View, { style: styles.featureBoxContent },
                        React.createElement(View, { style: styles.featureBoxDescription },
                            React.createElement(Text, { style: styles.tagText }, props.landingSceneText || s.strings.landing_tagline))),
                    React.createElement(View, { style: styles.createButtonBox },
                        React.createElement(MainButton, { testID: "createAccountButton", label: s.strings.landing_create_account_button, type: "secondary", onPress: handleCreate })),
                    React.createElement(View, { style: styles.loginButtonBox },
                        React.createElement(MainButton, { testID: "alreadyHaveAccountButton", onPress: handlePassword, label: s.strings.landing_already_have_account, type: "textOnly" })))))));
};
const BackgroundImageView = (props) => {
    return (React.createElement(View, { style: styles.container },
        React.createElement(BackgroundImage, { branding: props.branding, content: props.children })));
};
const styles = {
    container: Styles.SceneStyle,
    inner: {
        position: 'relative',
        flex: 1,
        width: '100%',
        height: '100%'
    },
    featureBox: {
        position: 'relative',
        top: scale(71),
        width: '100%',
        height: scale(286)
    },
    featureBoxContent: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        flexDirection: 'column',
        height: scale(166),
        alignItems: 'center',
        justifyContent: 'flex-start'
    },
    featureBoxDescription: {
        // height: scale(186), 306- 125 - remaining space.
        width: '100%',
        justifyContent: 'flex-end'
    },
    createButtonBox: {
        alignSelf: 'center',
        width: '70%'
    },
    loginButtonBox: {
        alignItems: 'center',
        justifyContent: 'flex-end',
        marginTop: scale(28)
    },
    tagText: {
        width: '80%',
        marginLeft: '10%',
        marginRight: '10%',
        color: Constants.WHITE,
        backgroundColor: Constants.TRANSPARENT,
        fontFamily: Constants.FONTS.fontFamilyRegular,
        textAlign: 'center',
        fontSize: scale(14),
        lineHeight: scale(18)
    },
    loginButton: {
        upStyle: Styles.TextOnlyButtonUpStyle,
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downStyle: Styles.TextOnlyButtonDownStyle
    }
};
