var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { useState } from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { login } from '../../actions/LoginAction';
import s from '../../common/locales/strings';
import { useDispatch, useSelector } from '../../types/ReduxTypes';
import { Tile } from '../common/Tile';
import { WarningCard } from '../common/WarningCard';
import { DateModal } from '../modals/DateModal';
import { TextInputModal } from '../modals/TextInputModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { MainButton } from '../themed/MainButton';
import { ThemedScene } from '../themed/ThemedScene';
export const RecoveryLoginScene = () => {
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const answerPrompt = s.strings.your_answer_label;
    const username = useSelector(state => state.login.username);
    const recoveryKey = useSelector(state => { var _a; return (_a = state.passwordRecovery.recoveryKey) !== null && _a !== void 0 ? _a : ''; });
    const questions = useSelector(state => state.passwordRecovery.userQuestions);
    const showCaseSensitivityWarning = questions.some(q => q.startsWith('text:') || !q.includes(':'));
    const [answers, setAnswers] = useState([]);
    const attemptLogin = (attempt) => __awaiter(void 0, void 0, void 0, function* () {
        return yield dispatch(login(attempt));
    });
    const saveOtpError = (attempt, error) => {
        dispatch({ type: 'OTP_ERROR', data: { attempt, error } });
    };
    const showDatePickerModal = (index) => {
        const now = new Date();
        Airship.show(bridge => (React.createElement(DateModal, { bridge: bridge, initialValue: now }))).then(answer => {
            const date = answer.toISOString().split('T')[0];
            answers[index] = date;
            setAnswers([...answers]);
        });
    };
    const showTextInputModal = (index) => {
        let minLengthString = questions[index].split(':')[1];
        if (minLengthString == null || minLengthString.trim() === '')
            minLengthString = '0';
        const minLength = parseInt(minLengthString);
        const validateAnswer = (answer) => __awaiter(void 0, void 0, void 0, function* () {
            return answer.length >= minLength
                ? true
                : sprintf(s.strings.min_length_error, minLength);
        });
        Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, title: sprintf(s.strings.recovery_answer, index + 1), inputLabel: s.strings.recovery_answer_placeholder, returnKeyType: "go", autoCapitalize: "none", autoCorrect: false, autoFocus: true, onSubmit: validateAnswer }))).then(text => {
            if (text == null)
                return;
            answers[index] = text;
            setAnswers([...answers]);
        });
    };
    const handleAnswer = (index) => () => {
        if (questions[index] == null)
            return;
        if (questions[index].startsWith('date:')) {
            showDatePickerModal(index);
        }
        else if (questions[index].startsWith('text:')) {
            showTextInputModal(index);
        }
        else {
            // Legacy Questions
            showTextInputModal(index);
        }
    };
    const handleSubmit = () => __awaiter(void 0, void 0, void 0, function* () {
        const okAnswers = answers.filter((a) => a != null);
        const attempt = {
            type: 'recovery',
            recoveryKey,
            username,
            answers: okAnswers
        };
        yield attemptLogin(attempt).catch(error => {
            if (error != null && error.name === 'OtpError') {
                saveOtpError(attempt, error);
            }
            else {
                const errorMessage = error != null
                    ? error.name === 'PasswordError'
                        ? s.strings.recovery_error
                        : error.message
                    : 'Unknown error';
                showError(errorMessage);
            }
        });
    });
    const renderQuestionAnswer = (index) => {
        var _a, _b, _c;
        return (React.createElement(View, null,
            React.createElement(Tile, { type: "static", title: sprintf(s.strings.recovery_question, index + 1), body: (_b = (_a = questions[index]) === null || _a === void 0 ? void 0 : _a.split(':').slice(-1)[0]) !== null && _b !== void 0 ? _b : sprintf(s.strings.recovery_question, index + 1) }),
            React.createElement(Tile, { type: "touchable", title: sprintf(s.strings.recovery_answer, index + 1), body: (_c = answers[index]) !== null && _c !== void 0 ? _c : answerPrompt, onPress: handleAnswer(index) })));
    };
    const renderForm = () => {
        return (React.createElement(View, { style: styles.formContainer },
            renderQuestionAnswer(0),
            renderQuestionAnswer(1),
            renderWarning()));
    };
    const renderWarning = () => {
        return showCaseSensitivityWarning ? (React.createElement(WarningCard, { title: s.strings.answer_case_sensitive, marginRem: 1 })) : null;
    };
    const renderSubmitButton = () => {
        return (React.createElement(View, { style: styles.buttonsContainer },
            React.createElement(MainButton, { alignSelf: "stretch", label: s.strings.submit, marginRem: [1, 0.5], onPress: handleSubmit, disabled: answers.length < questions.length || answers.some(a => a == null), type: "secondary" })));
    };
    return (React.createElement(ThemedScene, { paddingRem: 0, onBack: () => dispatch({ type: 'START_PASSWORD_LOGIN' }) },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            renderForm(),
            renderSubmitButton())));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        marginTop: theme.rem(1.5)
    },
    formContainer: {
        width: '100%',
        marginBottom: theme.rem(1)
    },
    buttonsContainer: {
        marginHorizontal: theme.rem(1),
        marginBottom: theme.rem(1)
    }
}));
