import * as React from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { confirmAndFinish } from '../../../actions/CreateAccountActions';
import { checkAndRequestNotifications } from '../../../actions/LoginInitActions';
import s from '../../../common/locales/strings';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { AccountInfo } from '../../themed/AccountInfo';
import { EdgeText } from '../../themed/EdgeText';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountReviewSceneComponent = ({ branding, onDone, theme }) => {
    const styles = getStyles(theme);
    const handleNext = () => {
        logEvent(`Signup_Review_Done`);
        onDone(branding);
    };
    return (React.createElement(ThemedScene, { title: s.strings.review },
        React.createElement(ScrollView, { contentContainerStyle: styles.content },
            React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, s.strings.tap_to_review_button),
            React.createElement(FormError, { marginRem: [0, 0, 2], title: s.strings.alert_dropdown_warning, numberOfLines: 2, isWarning: true }, s.strings.warning_message),
            React.createElement(AccountInfo, { marginRem: [0, 2.5] }),
            React.createElement(View, { style: styles.actions },
                React.createElement(MainButton, { label: s.strings.create, type: "secondary", onPress: handleNext })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(1.5)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(2)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(5),
        minHeight: theme.rem(3)
    }
}));
export const NewAccountReviewScene = connect((state) => ({}), (dispatch) => ({
    onDone(branding) {
        dispatch(confirmAndFinish());
        dispatch(checkAndRequestNotifications(branding)).catch(error => console.log(error));
    }
}))(withTheme(NewAccountReviewSceneComponent));
