import * as React from 'react';
import { Text, TouchableOpacity, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
export function ModalTitle(props) {
    const { center, children, icon = null, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(View, { style: styles.titleContainer },
        icon ? React.createElement(View, { style: styles.titleIconContainer }, icon) : null,
        React.createElement(Text, { style: [styles.titleText, center ? styles.titleCenter : null, padding] }, children)));
}
export function ModalMessage(props) {
    const { children, isWarning, paddingRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 0), theme.rem));
    return (React.createElement(Text, { style: [styles.messageText, padding, isWarning && styles.warningText] }, children));
}
export function ModalCloseArrow(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return (React.createElement(TouchableOpacity, { onPress: props.onPress, style: styles.closeArrow },
        React.createElement(AntDesignIcon, { name: "close", size: theme.rem(1.25), color: theme.iconTappable })));
}
const getStyles = cacheStyles((theme) => ({
    closeArrow: {
        alignItems: 'center',
        paddingTop: theme.rem(1)
    },
    titleContainer: {
        alignItems: 'center',
        flexDirection: 'row',
        margin: theme.rem(0.5)
    },
    titleIconContainer: {
        marginRight: theme.rem(0.5)
    },
    titleText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1.2),
        marginVertical: theme.rem(0.5)
    },
    titleCenter: {
        textAlign: 'center'
    },
    warningText: {
        color: theme.warningText
    },
    messageText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        marginVertical: theme.rem(0.5),
        textAlign: 'left'
    }
}));
