var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { format } from 'date-fns';
export const toLocalTime = (date) => format(date, 'MMM d, yyyy h:mm aa');
export function snooze(ms) {
    return __awaiter(this, void 0, void 0, function* () {
        return yield new Promise(resolve => setTimeout(resolve, ms));
    });
}
export function asyncWaterfall(asyncFuncs, timeoutMs = 5000) {
    return __awaiter(this, void 0, void 0, function* () {
        let pending = asyncFuncs.length;
        const promises = [];
        for (const func of asyncFuncs) {
            const index = promises.length;
            promises.push(func().catch(e => {
                e.index = index;
                throw e;
            }));
            if (pending > 1) {
                promises.push(new Promise(resolve => {
                    snooze(timeoutMs).then(() => {
                        resolve('async_waterfall_timed_out');
                    });
                }));
            }
            try {
                const result = yield Promise.race(promises);
                if (result === 'async_waterfall_timed_out') {
                    promises.pop();
                    --pending;
                }
                else {
                    return result;
                }
            }
            catch (e) {
                const i = e.index;
                promises.splice(i, 1);
                promises.pop();
                --pending;
                if (!pending) {
                    throw e;
                }
            }
        }
    });
}
export const shuffleArray = (array) => {
    let currentIndex = array.length;
    let temporaryValue, randomIndex;
    // While there remain elements to shuffle...
    while (currentIndex !== 0) {
        // Pick a remaining element...
        randomIndex = Math.floor(Math.random() * currentIndex);
        currentIndex -= 1;
        // And swap it with the current element.
        temporaryValue = array[currentIndex];
        array[currentIndex] = array[randomIndex];
        array[randomIndex] = temporaryValue;
    }
    return array;
};
// Based on https://stackoverflow.com/a/46181
export const validateEmail = (email) => {
    return email
        .toLowerCase()
        .match(/^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/);
};
